From b0aa9687fd29a4a2f4def647fb1875da3fd97d89 Mon Sep 17 00:00:00 2001
From: Aditya Vidyadhar Kamath <Aditya.Kamath1@ibm.com>
Date: Thu, 27 Apr 2023 04:28:21 -0500
Subject: [PATCH] Fix Assertion pid != 0 failure in AIX.

In AIX if there is a main and a thread created from it , then once the
program completed execution and goes to pd_disable () inferior_ptid
had pid 0 leading to an assertion failure while finding the thread's data
in aix-thread.c file.

This patch is a fix for the same.
---
 gdb/aix-thread.c | 7 +++++++
 1 file changed, 7 insertions(+)

diff --git a/gdb/aix-thread.c b/gdb/aix-thread.c
index df843d3c487..63d8c5179b1 100644
--- a/gdb/aix-thread.c
+++ b/gdb/aix-thread.c
@@ -1106,6 +1106,13 @@ static void
 pd_disable (void)
 {
   struct aix_thread_variables *data;
+  
+  /* If a thread exits and it is the only thread apart from 
+     main, inferior_ptid.pid () will be 0. Hence the below
+     condition to avoid pid != 0 assertion.  */
+  if (inferior_ptid.pid () == 0)
+    return;
+
   data = get_thread_data_helper_for_ptid (inferior_ptid);
 
   if (!data->pd_able)
-- 
2.38.3

